==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/features/sharding/core/src/main/java/org/apache/shardingsphere/sharding/exception/algorithm/DuplicateInsertDataRecordException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.exception.algorithm;

import org.apache.shardingsphere.infra.exception.core.external.sql.sqlstate.XOpenSQLState;
import org.apache.shardingsphere.sharding.exception.ShardingSQLException;
import org.apache.shardingsphere.sharding.route.engine.condition.ShardingConditions;

/**
 * Duplicate insert data record exception.
 */
public final class DuplicateInsertDataRecordException extends ShardingSQLException {
    
    private static final long serialVersionUID = -3448883456909841322L;
    
    public DuplicateInsertDataRecordException(final ShardingConditions shardingConditions, final String tableName) {
        super(XOpenSQLState.CHECK_OPTION_VIOLATION, 56, "Please check your sharding conditions '%s' to avoid same record in table '%s' routing to multiple data nodes.", shardingConditions, tableName);
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/sharding/core/src/main/java/org/apache/shardingsphere/sharding/exception/algorithm/DuplicateInsertDataRecordException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.exception.algorithm;

import org.apache.shardingsphere.infra.exception.external.sql.sqlstate.XOpenSQLState;
import org.apache.shardingsphere.sharding.exception.ShardingSQLException;
import org.apache.shardingsphere.sharding.route.engine.condition.ShardingConditions;

/**
 * Duplicate insert data record exception.
 */
public final class DuplicateInsertDataRecordException extends ShardingSQLException {
    
    private static final long serialVersionUID = -3448883456909841322L;
    
    public DuplicateInsertDataRecordException(final ShardingConditions shardingConditions, final String tableName) {
        super(XOpenSQLState.CHECK_OPTION_VIOLATION, 56, "Please check your sharding conditions '%s' to avoid same record in table '%s' routing to multiple data nodes.", shardingConditions, tableName);
    }
}
